@@ -16,8 +16,8 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
 	"github.com/ghodss/yaml"
-	operatorconfig "github.com/open-cluster-management/multicluster-observability-operator/operators/pkg/config"
 	cmomanifests "github.com/openshift/cluster-monitoring-operator/pkg/manifests"
+	operatorconfig "github.com/stolostron/multicluster-observability-operator/operators/pkg/config"
 )
 
 const (
