@@ -22,12 +22,12 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
-	mcoshared "github.com/open-cluster-management/multicluster-observability-operator/operators/multiclusterobservability/api/shared"
-	mcov1beta1 "github.com/open-cluster-management/multicluster-observability-operator/operators/multiclusterobservability/api/v1beta1"
-	mcov1beta2 "github.com/open-cluster-management/multicluster-observability-operator/operators/multiclusterobservability/api/v1beta2"
-	"github.com/open-cluster-management/multicluster-observability-operator/operators/multiclusterobservability/pkg/config"
-	operatorconfig "github.com/open-cluster-management/multicluster-observability-operator/operators/pkg/config"
-	"github.com/open-cluster-management/multicluster-observability-operator/operators/pkg/util"
+	mcoshared "github.com/stolostron/multicluster-observability-operator/operators/multiclusterobservability/api/shared"
+	mcov1beta1 "github.com/stolostron/multicluster-observability-operator/operators/multiclusterobservability/api/v1beta1"
+	mcov1beta2 "github.com/stolostron/multicluster-observability-operator/operators/multiclusterobservability/api/v1beta2"
+	"github.com/stolostron/multicluster-observability-operator/operators/multiclusterobservability/pkg/config"
+	operatorconfig "github.com/stolostron/multicluster-observability-operator/operators/pkg/config"
+	"github.com/stolostron/multicluster-observability-operator/operators/pkg/util"
 	workv1 "open-cluster-management.io/api/work/v1"
 )
 
@@ -57,7 +57,7 @@ var (
 type MetricsAllowlist struct {
 	NameList  []string          `yaml:"names"`
 	MatchList []string          `yaml:"matches"`
-	ReNameMap map[string]string `yaml:"renames"`
+	RenameMap map[string]string `yaml:"renames"`
 	RuleList  []Rule            `yaml:"rules"`
 }
 
@@ -298,7 +298,9 @@ func createManifestWorks(c client.Client, restMapper meta.RESTMapper,
 	}
 
 	// replace the managedcluster image with the custom registry
+	managedClusterImageRegistryMutex.RLock()
 	_, hasCustomRegistry := managedClusterImageRegistry[clusterName]
+	managedClusterImageRegistryMutex.RUnlock()
 	imageRegistryClient := NewImageRegistryClient(c)
 
 	// inject the endpoint operator deployment
@@ -498,8 +500,8 @@ func generateMetricsListCM(client client.Client) (*corev1.ConfigMap, error) {
 		allowlist.NameList = mergeMetrics(allowlist.NameList, customAllowlist.NameList)
 		allowlist.MatchList = mergeMetrics(allowlist.MatchList, customAllowlist.MatchList)
 		allowlist.RuleList = append(allowlist.RuleList, customAllowlist.RuleList...)
-		for k, v := range customAllowlist.ReNameMap {
-			allowlist.ReNameMap[k] = v
+		for k, v := range customAllowlist.RenameMap {
+			allowlist.RenameMap[k] = v
 		}
 	} else {
 		log.Info("There is no custom metrics allowlist configmap in the cluster")
