@@ -7,6 +7,7 @@ import (
 	"context"
 	"errors"
 	"reflect"
+	"sync"
 	"time"
 
 	"github.com/go-logr/logr"
@@ -32,12 +33,13 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
-	mcov1beta1 "github.com/open-cluster-management/multicluster-observability-operator/operators/multiclusterobservability/api/v1beta1"
-	mcov1beta2 "github.com/open-cluster-management/multicluster-observability-operator/operators/multiclusterobservability/api/v1beta2"
-	"github.com/open-cluster-management/multicluster-observability-operator/operators/multiclusterobservability/pkg/config"
-	"github.com/open-cluster-management/multicluster-observability-operator/operators/multiclusterobservability/pkg/util"
-	commonutil "github.com/open-cluster-management/multicluster-observability-operator/operators/pkg/util"
-	mchv1 "github.com/open-cluster-management/multiclusterhub-operator/pkg/apis/operator/v1"
+	mcov1beta1 "github.com/stolostron/multicluster-observability-operator/operators/multiclusterobservability/api/v1beta1"
+	mcov1beta2 "github.com/stolostron/multicluster-observability-operator/operators/multiclusterobservability/api/v1beta2"
+	"github.com/stolostron/multicluster-observability-operator/operators/multiclusterobservability/pkg/config"
+	"github.com/stolostron/multicluster-observability-operator/operators/multiclusterobservability/pkg/util"
+	operatorconfig "github.com/stolostron/multicluster-observability-operator/operators/pkg/config"
+	commonutil "github.com/stolostron/multicluster-observability-operator/operators/pkg/util"
+	mchv1 "github.com/stolostron/multiclusterhub-operator/pkg/apis/operator/v1"
 	addonv1alpha1 "open-cluster-management.io/api/addon/v1alpha1"
 	clusterv1 "open-cluster-management.io/api/cluster/v1"
 	workv1 "open-cluster-management.io/api/work/v1"
@@ -57,6 +59,7 @@ var (
 	isClusterManagementAddonCreated = false
 	isplacementControllerRunnning   = false
 	managedClusterList              = map[string]string{}
+	managedClusterListMutex         = &sync.RWMutex{}
 )
 
 // PlacementRuleReconciler reconciles a PlacementRule object
@@ -112,6 +115,11 @@ func (r *PlacementRuleReconciler) Reconcile(ctx context.Context, req ctrl.Reques
 		return ctrl.Result{}, nil
 	}
 
+	if !deleteAll && !mco.Spec.ObservabilityAddonSpec.EnableMetrics {
+		reqLogger.Info("EnableMetrics is set to false. Delete Observability addons")
+		deleteAll = true
+	}
+
 	// check if the MCH CRD exists
 	mchCrdExists, _ := r.CRDMap[config.MCHCrdName]
 	// requeue after 10 seconds if the mch crd exists and image image manifests map is empty
@@ -300,6 +308,7 @@ func createAllRelatedRes(
 	}
 
 	failedCreateManagedClusterRes := false
+	managedClusterListMutex.RLock()
 	for managedCluster, openshiftVersion := range managedClusterList {
 		currentClusters = commonutil.Remove(currentClusters, managedCluster)
 		// enter the loop for the following reconcile requests:
@@ -336,6 +345,7 @@ func createAllRelatedRes(
 			}
 		}
 	}
+	managedClusterListMutex.RUnlock()
 
 	failedDeleteOba := false
 	for _, cluster := range currentClusters {
@@ -445,6 +455,8 @@ func deleteManagedClusterRes(c client.Client, namespace string) error {
 }
 
 func updateManagedClusterList(obj client.Object) {
+	managedClusterListMutex.Lock()
+	defer managedClusterListMutex.Unlock()
 	if version, ok := obj.GetLabels()["openshiftVersion"]; ok {
 		managedClusterList[obj.GetName()] = version
 	} else {
@@ -468,8 +480,12 @@ func (r *PlacementRuleReconciler) SetupWithManager(mgr ctrl.Manager) error {
 			if e.ObjectNew.GetResourceVersion() != e.ObjectOld.GetResourceVersion() {
 				if e.ObjectNew.GetDeletionTimestamp() != nil {
 					log.Info("managedcluster is in terminating state", "managedCluster", e.ObjectNew.GetName())
+					managedClusterListMutex.Lock()
 					delete(managedClusterList, e.ObjectNew.GetName())
+					managedClusterListMutex.Unlock()
+					managedClusterImageRegistryMutex.Lock()
 					delete(managedClusterImageRegistry, e.ObjectNew.GetName())
+					managedClusterImageRegistryMutex.Unlock()
 				} else {
 					updateManagedClusterList(e.ObjectNew)
 					updateManagedClusterImageRegistry(e.ObjectNew)
@@ -480,8 +496,12 @@ func (r *PlacementRuleReconciler) SetupWithManager(mgr ctrl.Manager) error {
 		},
 		DeleteFunc: func(e event.DeleteEvent) bool {
 			log.Info("DeleteFunc", "managedCluster", e.Object.GetName())
+			managedClusterListMutex.Lock()
 			delete(managedClusterList, e.Object.GetName())
+			managedClusterListMutex.Unlock()
+			managedClusterImageRegistryMutex.Lock()
 			delete(managedClusterImageRegistry, e.Object.GetName())
+			managedClusterImageRegistryMutex.Unlock()
 			return true
 		},
 	}
@@ -535,33 +555,36 @@ func (r *PlacementRuleReconciler) SetupWithManager(mgr ctrl.Manager) error {
 		},
 	}
 
-	customAllowlistPred := predicate.Funcs{
+	allowlistPred := predicate.Funcs{
 		CreateFunc: func(e event.CreateEvent) bool {
-			if e.Object.GetName() == config.AllowlistCustomConfigMapName &&
+			if (e.Object.GetName() == config.AllowlistCustomConfigMapName ||
+				e.Object.GetName() == operatorconfig.AllowlistConfigMapName) &&
 				e.Object.GetNamespace() == config.GetDefaultNamespace() {
 				// generate the metrics allowlist configmap
-				log.Info("generate metric allow list configmap for custom configmap CREATE")
+				log.Info("generate metric allow list configmap for allowlist configmap CREATE")
 				metricsAllowlistConfigMap, _ = generateMetricsListCM(c)
 				return true
 			}
 			return false
 		},
 		UpdateFunc: func(e event.UpdateEvent) bool {
-			if e.ObjectNew.GetName() == config.AllowlistCustomConfigMapName &&
+			if (e.ObjectNew.GetName() == config.AllowlistCustomConfigMapName ||
+				e.ObjectNew.GetName() == operatorconfig.AllowlistConfigMapName) &&
 				e.ObjectNew.GetNamespace() == config.GetDefaultNamespace() &&
 				e.ObjectNew.GetResourceVersion() != e.ObjectOld.GetResourceVersion() {
 				// regenerate the metrics allowlist configmap
-				log.Info("generate metric allow list configmap for custom configmap UPDATE")
+				log.Info("generate metric allow list configmap for allowlist configmap UPDATE")
 				metricsAllowlistConfigMap, _ = generateMetricsListCM(c)
 				return true
 			}
 			return false
 		},
 		DeleteFunc: func(e event.DeleteEvent) bool {
-			if e.Object.GetName() == config.AllowlistCustomConfigMapName &&
+			if (e.Object.GetName() == config.AllowlistCustomConfigMapName ||
+				e.Object.GetName() == operatorconfig.AllowlistConfigMapName) &&
 				e.Object.GetNamespace() == config.GetDefaultNamespace() {
 				// regenerate the metrics allowlist configmap
-				log.Info("generate metric allow list configmap for custom configmap UPDATE")
+				log.Info("generate metric allow list configmap for allowlist configmap UPDATE")
 				metricsAllowlistConfigMap, _ = generateMetricsListCM(c)
 				return true
 			}
@@ -737,7 +760,7 @@ func (r *PlacementRuleReconciler) SetupWithManager(mgr ctrl.Manager) error {
 			}
 		}), builder.WithPredicates(mcoPred)).
 		// secondary watch for custom allowlist configmap
-		Watches(&source.Kind{Type: &corev1.ConfigMap{}}, &handler.EnqueueRequestForObject{}, builder.WithPredicates(customAllowlistPred)).
+		Watches(&source.Kind{Type: &corev1.ConfigMap{}}, &handler.EnqueueRequestForObject{}, builder.WithPredicates(allowlistPred)).
 		// secondary watch for certificate secrets
 		Watches(&source.Kind{Type: &corev1.Secret{}}, &handler.EnqueueRequestForObject{}, builder.WithPredicates(certSecretPred)).
 		// secondary watch for alertmanager accessor serviceaccount
